==> MightyWeb-Webview-Web-to-App-Convertor-V29.0[www.persianone.ir].zip: webly_flutter/lib/utils/constant.dart <==
//With PHP backend
const BASE_URL = "https://apps.meetmighty.com/mightyweb";

//without PHP backend
const PURCHASE_CODE = '';
const BASE_URL_OFFLINE =
    'https://meetmighty.com/mightyweb-public/view/getjson.php?user=$PURCHASE_CODE';

//preference
const mOneSignalID = 'mOne_signal_id';

//Counter to show Interstitial Ad
const int InterstitialTap = 3;
int adClickCounter = 0;

//AdmobId
const adMobBannerId = "admob_banner_id";
const adMobInterstitialId = "admob_interstitial_id";
const adMobBannerIdIos = "admob_banner_id_ios";
const adMobInterstitialIdIos = "admob_interstitial_id_ios";

// Facebook
const FACEBOOK_KEY = '';
const fbBannerId = "facebook_banner_id";
const fbBannerIdIos = "";
const fbInterstitialId = "facebook_interstitial_id";
const fbInterstitialIdIos = "";

const APPNAME = 'appName';
const APPLOGO = 'appLogo';
const URL = 'url';
const ISFULLSCREEN = 'ISFULLSCREEN';
const IS_JAVASCRIPT_ENABLE = 'isJavascriptEnable';
const IS_SPLASH_SCREEN = 'isSplashScreen';
const APP_LANGUAGE = 'appLanuguage';
const IS_ZOOM_FUNCTIONALITY = 'isZoomFunctionality';
const NAVIGATIONSTYLE = 'NAVIGATIONSTYLE';
const HEADERSTYLE = 'HEADERSTYLE';
const IS_WEBRTC = 'IS_WEBRTC';
const IS_WALKTHROUGH = 'IS_WALKTHROUGH';
const WALKTHROUGH = 'WALKTHROUGH';
const FLOATING_LOGO = 'FLOATING_LOGO';
const IS_FLOATING = 'IS_FLOATING';
const FLOATING_STYLE = 'FLOATING_STYLE';
const FLOATING_DATA = 'FLOATING_DATA';
const TAB_BAR_STYLE = 'TAB_BAR_STYLE';
const IS_PULL_TO_REFRESH = 'IS_PULL_TO_REFRESH';
const IS_COOKIE = 'IS_COOKIE';
const BOTTOM_NAVIGATION_STYLE = 'BOTTOM_NAVIGATION_STYLE';
const WALK_THROUGH_STYLE = 'WALK_THROUGH_STYLE';
const IS_Exit_POP_UP = 'IS_Exit_POP_UP';
const DISABLE_HEADER = 'DISABLE_HEADER';
const DISABLE_FOOTER = 'DISABLE_FOOTER';
const DISABLE_LEFT_ICON = 'DISABLE_LEFT_ICON';

const AD_MOB_BANNER_ID = 'admobBannerID';
const AD_MOB_INTERSTITIAL_ID = 'admobIntentialID';
const AD_MOB_BANNER_ID_IOS = 'admobBannerIDIOS';
const AD_MOB_INTERSTITIAL_ID_IOS = 'admobIntentialIDIOS';

const FACEBOOK_BANNER_PLACEMENT_ID = "facebookBannerID";
const FACEBOOK_INTERSTITIAL_PLACEMENT_ID = "facebookIntentialID";
const FACEBOOK_BANNER_PLACEMENT_ID_IOS = "facebookBannerIDIOS";
const FACEBOOK_INTERSTITIAL_PLACEMENT_ID_IOS = "facebookIntentialIDIOS";

const ADD_TYPE = 'ads_type';
const NONE = 'none';

String isGoogleAds = "admob";
String isFacebookAds = "facebook";

const LOADER_STYLE = 'loaderStyle';
const IS_LOADER = 'is_progressbar';

const THEME_STYLE = 'themeStyle';
const GRADIENT1 = 'GRADIENT1';
const GRADIENT2 = 'GRADIENT2';
const CUSTOM_COLOR = 'customColor';

const IS_SHOW_ABOUT = 'isShowAbout';
const WHATS_APP_NUMBER = 'whatsAppNumber';
const INSTA_GRAM_URL = 'instagramUrl';
const TWITTER_URL = 'twitterUrl';
const FACEBOOK_URL = 'facebookUrl';
const CALL_NUMBER = 'callNumber';
const SKYPE = 'skype';
const SNAPCHAT = 'snapchat';
const YOUTUBE = 'youtube';
const MESSENGER = 'messenger';
const COPYRIGHT = 'copyright';
const DESCRIPTION = 'description';

const MENU_STYLE = 'menu_Style';

const LEFTICON = 'leftIcon';
const RIGHTICON = 'righticon';
const BOTTOMMENU = 'BOTTOMMENU';
const BOTTOMSIDEMENU = 'BOTTOMSIDEMENU';

const ONESINGLE = 'onesingal';
const IS_FIRST_TIME = 'IS_FIRST_TIME';

const IS_FROM_TRY_WEBSITE = 'is_from_try_website';
const DETAIL_PAGE_VARIANT = 'DetailPageVariant';
const DETAIL_PAGE_VARIANT1 = 'DetailPageVariant1';
const THEME_VARIANT = 'ThemeVariant';
const LOADER_VARIANT = 'LoaderVariant';
const isDarkModeOnPref = 'isDarkModeOnPref';

const USER_AGENT = 'USER_AGENT';
const TABS = 'TABS';
const PAGES = 'PAGES';

// Check Value
const RIGHT_ICON_RELOAD = "ic_reload";
const RIGHT_ICON_SHARE = "ic_share";
const RIGHT_ICON_CLOSE = "ic_close";
const RIGHT_ICON_EXIT = "ic_exit";
const RIGHT_ICON_SEARCH = "ic_search";
const RIGHT_ICON_SETTINGS = "ic_settings";
const RIGHT_ICON_CART = "ic_cart";
const RIGHT_ICON_PROFILE = "ic_profile";
const RIGHT_ICON_MESSAGE = "ic_message";
const RIGHT_ICON_NOTIFICATION = "ic_notification";
const RIGHT_ICON_USER = "ic_user";
const RIGHT_ICON_LIST = "ic_list";
const RIGHT_ICON_GRID = "ic_grid";
const RIGHT_ICON_FILTER = "ic_filter";
const RIGHT_ICON_FAVOURITE = "ic_favourite";
const RIGHT_ICON_CHAT = "ic_chat";
const RIGHT_ICON_ABOUT = "ic_about";
const RIGHT_ICON_SCAN = "ic_qr_code";

const LEFT_ICON_BACK_1 = "ic_back1";
const LEFT_ICON_BACK_2 = "ic_back2";
const LEFT_ICON_HOME = "ic_home";
const LEFT_ICON_PROFILE = "ic_profile";
const LEFT_ICON_CLOSE = "ic_close";
const LEFT_ICON_SEARCH = "ic_search";
const LEFT_ICON_ADD = "ic_add";

const HEADER_STYLE_CENTER = "center";
const HEADER_STYLE_LEFT = "left";
const HEADER_STYLE_EMPTY = "empty_header";

const THEME_STYLE_GRADIENT = "Gradient";
const THEME_STYLE_DEFAULT = "Default";
const THEME_STYLE_CUSTOM = "Custom";

const NAVIGATION_STYLE_SIDE_DRAWER = "sidedrawer";
const NAVIGATION_STYLE_BOTTOM_NAVIGATION = "bottom_navigation";
const NAVIGATION_STYLE_FULL_SCREEN = "fullscreen";
const NAVIGATION_STYLE_TAB_BAR = "tabs";
const NAVIGATION_STYLE_SIDE_DRAWER_TABS = "sidedrawer_tabs";
const NAVIGATION_STYLE_BOTTOM_NAVIGATION_SIDE_DRAWER =
    "sidedrawer_bottom_navigation";
// bool isLeftIconVisible = true;

const SIMPLE_TAB = "simple_tab";
const TAB_WITH_ICON = "tab_with_icon";
const TAB_WITH_ICON_TITLE = "tab_with_title_icon";

const WALK_THROUGH_1 = "walkthrough_style_1";
const WALK_THROUGH_2 = "walkthrough_style_2";
const WALK_THROUGH_3 = "walkthrough_style_3";

const BOTTOM_NAVIGATION_1 = "bottom_navigation_1";
const BOTTOM_NAVIGATION2 = "bottom_navigation_2";
const BOTTOM_NAVIGATION3 = "bottom_navigation_3";

const SPLASH_FIRST_COLOR = 'first_color';
const SPLASH_SECOND_COLOR = 'second_color';
const SPLASH_TITLE = 'title';
const SPLASH_ENABLE_TITLE = 'enable_title';
const SPLASH_ENABLE_LOGO = 'enable_logo';
const SPLASH_ENABLE_BACKGROUND = 'enable_background';
const SPLASH_LOGO_URL = 'splash_logo_url';
const SPLASH_TITLE_COLOR = 'title_color';
const SPLASH_BACKGROUND_URL = 'splash_background_url';

const EXIST_ICON = 'exit_image_url';
const EXIST_TITLE = 'EXIST_TITLE';
const EXIST_NEGATIVE_TEXT = 'negative_text';
const EXIST_POSITIVE_TEXT = 'positive_text';
const EXIST_ENABLE_ICON = 'enable_image';

const SHARE_CONTENT = 'share_content';

//Theme color
List<String> themeName = [
  'Theme1',
  'Theme2',
  'Theme3',
  'Theme4',
  'Theme5',
  'Theme6',
  "Theme7",
  "Theme8",
  "Theme9",
  "Theme10",
  "Theme11",
  "Theme12",
  "Theme13",
  "Theme14",
  "Theme15",
];

List<String> colorName = [
  "#880e4f",
  "#e667b1",
  "#4a148c",
  "#b71c1c",
  "#1a237e",
  "#0d47a1",
  "#01579b",
  "#094c4f",
  "#bfc726",
  "#1b5e20",
  "#ba8d06",
  "#6835f2",
  "#212121",
  "#263238",
  "#dd2c00",
  '#1b5ddb',
];

List<String> loaderName = [
  "RotatingPlane",
  "DoubleBounce",
  "WanderingCubes",
  "Pulse",
  "ChasingDots",
  "FadingFour",
  "Circle",
  "CubeGrid",
  "FadingCircle",
  "FoldingCube",
  "RotatingCircle",
  "Wave",
  "Ring",
];

// Visibility
const EnableHome = false;
const EnableDemo = false;
const EnableMode = true;

==> MightyWeb-Webview-Web-to-App-Convertor-V30.0[www.persianone.ir].zip: webly_flutter/lib/utils/constant.dart <==
//With PHP backend
const BASE_URL = "https://apps.meetmighty.com/mightyweb";

//without PHP backend
const PURCHASE_CODE = '';
const BASE_URL_OFFLINE = 'https://meetmighty.com/mightyweb-public/view/getjson.php?user=$PURCHASE_CODE';

//preference
const mOneSignalID = 'oneSignal_id';

//Counter to show Interstitial Ad
// const int InterstitialTap = 3;
const INTERSTITIAL_TAP_COUNT = 'interstitial_ad_tap_count';
const DEFAULT_INTERSTITIAL_TAP_COUNT = 0;
int adClickCounter = 0;

//AdmobId
const adMobBannerId = "admob_banner_id";
const adMobInterstitialId = "admob_interstitial_id";
const adMobBannerIdIos = "admob_banner_id_ios";
const adMobInterstitialIdIos = "admob_interstitial_id_ios";

// Facebook
const FACEBOOK_KEY = '';
const fbBannerId = "facebook_banner_id";
const fbBannerIdIos = "";
const fbInterstitialId = "facebook_interstitial_id";
const fbInterstitialIdIos = "";

const APPNAME = 'appName';
const APPLOGO = 'appLogo';
const URL = 'url';
const ISFULLSCREEN = 'ISFULLSCREEN';
const IS_JAVASCRIPT_ENABLE = 'isJavascriptEnable';
const IS_SPLASH_SCREEN = 'isSplashScreen';
const APP_LANGUAGE = 'appLanuguage';
const IS_ZOOM_FUNCTIONALITY = 'isZoomFunctionality';
const NAVIGATIONSTYLE = 'NAVIGATIONSTYLE';
const HEADERSTYLE = 'HEADERSTYLE';
const IS_WEBRTC = 'IS_WEBRTC';
const IS_WALKTHROUGH = 'IS_WALKTHROUGH';
const WALKTHROUGH = 'WALKTHROUGH';
const FLOATING_LOGO = 'FLOATING_LOGO';
const IS_FLOATING = 'IS_FLOATING';
const FLOATING_STYLE = 'FLOATING_STYLE';
const FLOATING_DATA = 'FLOATING_DATA';
const TAB_BAR_STYLE = 'TAB_BAR_STYLE';
const IS_PULL_TO_REFRESH = 'IS_PULL_TO_REFRESH';
const IS_COOKIE = 'IS_COOKIE';
const BOTTOM_NAVIGATION_STYLE = 'BOTTOM_NAVIGATION_STYLE';
const WALK_THROUGH_STYLE = 'WALK_THROUGH_STYLE';
const IS_Exit_POP_UP = 'IS_Exit_POP_UP';
const DISABLE_HEADER = 'DISABLE_HEADER';
const DISABLE_FOOTER = 'DISABLE_FOOTER';
const DISABLE_LEFT_ICON = 'DISABLE_LEFT_ICON';


const AD_MOB_BANNER_ID = 'admobBannerID';
const AD_MOB_INTERSTITIAL_ID = 'admobIntentialID';
const AD_MOB_BANNER_ID_IOS = 'admobBannerIDIOS';
const AD_MOB_INTERSTITIAL_ID_IOS = 'admobIntentialIDIOS';

const FACEBOOK_BANNER_PLACEMENT_ID = "facebookBannerID";
const FACEBOOK_INTERSTITIAL_PLACEMENT_ID = "facebookIntentialID";
const FACEBOOK_BANNER_PLACEMENT_ID_IOS = "facebookBannerIDIOS";
const FACEBOOK_INTERSTITIAL_PLACEMENT_ID_IOS = "facebookIntentialIDIOS";

const ADD_TYPE = 'ads_type';
const NONE = 'none';

String isGoogleAds = "admob";
String isFacebookAds = "facebook";

const LOADER_STYLE = 'loaderStyle';
const IS_LOADER = 'is_progressbar';

const THEME_STYLE = 'themeStyle';
const GRADIENT1 = 'GRADIENT1';
const GRADIENT2 = 'GRADIENT2';
const CUSTOM_COLOR = 'customColor';

const IS_SHOW_ABOUT = 'isShowAbout';
const WHATS_APP_NUMBER = 'whatsAppNumber';
const INSTA_GRAM_URL = 'instagramUrl';
const TWITTER_URL = 'twitterUrl';
const FACEBOOK_URL = 'facebookUrl';
const CALL_NUMBER = 'callNumber';
const SKYPE = 'skype';
const SNAPCHAT = 'snapchat';
const YOUTUBE = 'youtube';
const MESSENGER = 'messenger';
const COPYRIGHT = 'copyright';
const DESCRIPTION = 'description';

const MENU_STYLE = 'menu_Style';

const LEFTICON = 'leftIcon';
const RIGHTICON = 'righticon';
const BOTTOMMENU = 'BOTTOMMENU';
const BOTTOMSIDEMENU = 'BOTTOMSIDEMENU';

const ONESINGLE = 'onesingal';
const IS_FIRST_TIME = 'IS_FIRST_TIME';

const IS_FROM_TRY_WEBSITE = 'is_from_try_website';
const DETAIL_PAGE_VARIANT = 'DetailPageVariant';
const DETAIL_PAGE_VARIANT1 = 'DetailPageVariant1';
const THEME_VARIANT = 'ThemeVariant';
const LOADER_VARIANT = 'LoaderVariant';
const isDarkModeOnPref = 'isDarkModeOnPref';

const USER_AGENT = 'USER_AGENT';
const TABS = 'TABS';
const PAGES = 'PAGES';

// Check Value
const RIGHT_ICON_RELOAD = "ic_reload";
const RIGHT_ICON_SHARE = "ic_share";
const RIGHT_ICON_CLOSE = "ic_close";
const RIGHT_ICON_EXIT = "ic_exit";
const RIGHT_ICON_SEARCH = "ic_search";
const RIGHT_ICON_SETTINGS = "ic_settings";
const RIGHT_ICON_CART = "ic_cart";
const RIGHT_ICON_PROFILE = "ic_profile";
const RIGHT_ICON_MESSAGE = "ic_message";
const RIGHT_ICON_NOTIFICATION = "ic_notification";
const RIGHT_ICON_USER = "ic_user";
const RIGHT_ICON_LIST = "ic_list";
const RIGHT_ICON_GRID = "ic_grid";
const RIGHT_ICON_FILTER = "ic_filter";
const RIGHT_ICON_FAVOURITE = "ic_favourite";
const RIGHT_ICON_CHAT = "ic_chat";
const RIGHT_ICON_ABOUT = "ic_about";
const RIGHT_ICON_SCAN = "ic_qr_code";

const LEFT_ICON_BACK_1 = "ic_back1";
const LEFT_ICON_BACK_2 = "ic_back2";
const LEFT_ICON_HOME = "ic_home";
const LEFT_ICON_PROFILE = "ic_profile";
const LEFT_ICON_CLOSE = "ic_close";
const LEFT_ICON_SEARCH = "ic_search";
const LEFT_ICON_ADD = "ic_add";

const HEADER_STYLE_CENTER = "center";
const HEADER_STYLE_LEFT= "left";
const HEADER_STYLE_EMPTY = "empty_header";

const THEME_STYLE_GRADIENT = "Gradient";
const THEME_STYLE_DEFAULT = "Default";
const THEME_STYLE_CUSTOM = "Custom";

const NAVIGATION_STYLE_SIDE_DRAWER = "sidedrawer";
const NAVIGATION_STYLE_BOTTOM_NAVIGATION = "bottom_navigation";
const NAVIGATION_STYLE_FULL_SCREEN = "fullscreen";
const NAVIGATION_STYLE_TAB_BAR = "tabs";
const NAVIGATION_STYLE_SIDE_DRAWER_TABS = "sidedrawer_tabs";
const NAVIGATION_STYLE_BOTTOM_NAVIGATION_SIDE_DRAWER = "sidedrawer_bottom_navigation";
// bool isLeftIconVisible = true;


const SIMPLE_TAB = "simple_tab";
const TAB_WITH_ICON = "tab_with_icon";
const TAB_WITH_ICON_TITLE = "tab_with_title_icon";

const WALK_THROUGH_1 = "walkthrough_style_1";
const WALK_THROUGH_2 = "walkthrough_style_2";
const WALK_THROUGH_3 = "walkthrough_style_3";

const BOTTOM_NAVIGATION_1 = "bottom_navigation_1";
const BOTTOM_NAVIGATION2 = "bottom_navigation_2";
const BOTTOM_NAVIGATION3 = "bottom_navigation_3";

const SPLASH_FIRST_COLOR = 'first_color';
const SPLASH_SECOND_COLOR = 'second_color';
const SPLASH_TITLE = 'title';
const SPLASH_ENABLE_TITLE = 'enable_title';
const SPLASH_ENABLE_LOGO = 'enable_logo';
const SPLASH_ENABLE_BACKGROUND = 'enable_background';
const SPLASH_LOGO_URL = 'splash_logo_url';
const SPLASH_TITLE_COLOR = 'title_color';
const SPLASH_BACKGROUND_URL = 'splash_background_url';

const EXIST_ICON = 'exit_image_url';
const EXIST_TITLE = 'EXIST_TITLE';
const EXIST_NEGATIVE_TEXT = 'negative_text';
const EXIST_POSITIVE_TEXT = 'positive_text';
const EXIST_ENABLE_ICON = 'enable_image';

const SHARE_CONTENT = 'share_content';

//Theme color
List<String> themeName = [
  'Theme1',
  'Theme2',
  'Theme3',
  'Theme4',
  'Theme5',
  'Theme6',
  "Theme7",
  "Theme8",
  "Theme9",
  "Theme10",
  "Theme11",
  "Theme12",
  "Theme13",
  "Theme14",
  "Theme15",
];

List<String> colorName = [
  "#880e4f",
  "#e667b1",
  "#4a148c",
  "#b71c1c",
  "#1a237e",
  "#0d47a1",
  "#01579b",
  "#094c4f",
  "#bfc726",
  "#1b5e20",
  "#ba8d06",
  "#6835f2",
  "#212121",
  "#263238",
  "#dd2c00",
  '#1b5ddb'
];

List<String> loaderName = [
  "RotatingPlane",
  "DoubleBounce",
  "WanderingCubes",
  "Pulse",
  "ChasingDots",
  "FadingFour",
  "Circle",
  "CubeGrid",
  "FadingCircle",
  "FoldingCube",
  "RotatingCircle",
  "Wave",
  "Ring",
];

// Visibility
const EnableHome = true;
const EnableDemo = false;
const EnableMode = true;
